@@ -4,7 +4,8 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '1.999826';
+our $VERSION = '1.999831';
+$VERSION =~ tr/_//d;
 
 use Carp;
 
@@ -2013,8 +2014,8 @@ Math::BigInt::Lib - virtual parent class for Math::BigInt libraries
 
     package Math::BigInt::MyBackend;
 
-    use Math::BigInt::lib;
-    our @ISA = qw< Math::BigInt::lib >;
+    use Math::BigInt::Lib;
+    our @ISA = qw< Math::BigInt::Lib >;
 
     sub _new { ... }
     sub _str { ... }
